@@ -165,7 +165,7 @@ def test_filefmt(mock_atexit_register):
         "%(asctime)s, %(name)s %(levelname)s %(message)s", datefmt="%H:%M:%S"
     )
 
-    with patch("builtins.open", mock_open()) as mock_file:
+    with patch("builtins.open", mock_open()):
         log_obj = log_handler.Logger(
             name="test_name",
             loggers=["log"],
@@ -206,21 +206,13 @@ def test_filecap(mock_os, mock_atexit_register):
         "%(asctime)s, %(name)s %(levelname)s %(message)s", datefmt="%H:%M:%S"
     )
 
-    # create mock files with different creation times
-    file1 = ("path/to/logs/file1.log", 1646106476)
-    file2 = ("path/to/logs/file2.log", 1646192876)
-    file3 = ("path/to/logs/file3.log", 1646279276)
-
-    # create a list of mock files
-    mock_files = [file1, file2, file3]
-
     with patch("builtins.open", mock_open()):
         # mock the os functions used inside the cap method
         mock_os.path.getctime.return_value = 1646106476
         mock_os.listdir.return_value = ["file1.log", "file2.log", "file3.log"]
 
         # create an instance of the Logger class
-        log_obj = log_handler.Logger(
+        log_handler.Logger(
             name="test_name",
             loggers=["log"],
             loglvl=logging.INFO,
@@ -281,7 +273,7 @@ def test_filecap_tomany(mock_os, mock_atexit_register):
         mock_os.listdir.return_value = [f[0].split("/")[-1] for f in mock_files]
 
         # create an instance of the Logger class with filecap set to 2
-        log_obj = log_handler.Logger(
+        log_handler.Logger(
             name="test_name",
             loggers=["log"],
             loglvl=logging.INFO,
@@ -357,7 +349,7 @@ def test_timeout(mock_os, mock_atexit_register):
             with patch("builtins.open", side_effect=mock_files), patch(
                 "warnings.warn"
             ) as mock_warn:
-                log_obj = log_handler.Logger(
+                log_handler.Logger(
                     name="test_name",
                     loggers=["log"],
                     loglvl=logging.INFO,
@@ -386,7 +378,7 @@ def test_timeout(mock_os, mock_atexit_register):
                 # reset the call count for remove mock object
                 mock_os.remove.call_count = 0
 
-                log_obj = log_handler.Logger(
+                log_handler.Logger(
                     name="test_name",
                     loggers=["log"],
                     loglvl=logging.INFO,
@@ -422,7 +414,7 @@ def test_out(mock_os, mock_atexit_register):
         "%(asctime)s, %(name)s %(levelname)s %(message)s", datefmt="%H:%M:%S"
     )
 
-    with patch("builtins.open", mock_open()) as mock_file:
+    with patch("builtins.open", mock_open()):
         # create an instance of the Logger class
         log_obj = log_handler.Logger(
             name="test_name",
@@ -481,7 +473,7 @@ def test_out_file_fail(capsys, mock_os, mock_atexit_register):
         "%(asctime)s, %(name)s %(levelname)s %(message)s", datefmt="%H:%M:%S"
     )
 
-    with patch("builtins.open", mock_open()) as mock_file:
+    with patch("builtins.open", mock_open()):
         # create an instance of the Logger class
         log_obj = log_handler.Logger(
             name="test_name",
@@ -520,7 +512,7 @@ def test_out_folder_fail(capsys, mock_os, mock_atexit_register):
         "%(asctime)s, %(name)s %(levelname)s %(message)s", datefmt="%H:%M:%S"
     )
 
-    with patch("builtins.open", mock_open()) as mock_file:
+    with patch("builtins.open", mock_open()):
         # create an instance of the Logger class
         log_obj = log_handler.Logger(
             name="test_name",
